@@ -39,8 +39,6 @@ extern crate error_chain;
 
 mod error;
 
-mod event_handler;
-
 mod func;
 
 mod static_libflo;
@@ -49,6 +47,4 @@ mod string;
 
 pub use error::*;
 
-pub use event_handler::*;
-
 pub use func::*;
