@@ -1,5 +1,5 @@
-pub fn get_libflo() -> &'static str {
-    "get_libflo"
+pub fn get() -> &'static str {
+    "get"
 }
 
 pub fn self_module_name() -> &'static str {
